class Product:
    """
    Represents a product with an ID, name, description, price, and quantity.
    """

    def __init__(self, id: str, name: str, description: str, price: float, quantity: int):
        """
        Initializes a new product.

        Args:
            id (str): The unique identifier for the product.
            name (str): The name of the product.
            description (str): A brief description of the product.
            price (float): The price of the product.
            quantity (int): The available quantity of the product.
        """
        self.id = id
        self.name = name
        self.description = description
        self.price = price
        self.quantity = quantity
        self.post_init()

    def post_init(self):
        """
        Validates the product's price.
        
        Raises:
            ValueError: If the price is negative.
        """
        if self.price < 0:
            raise ValueError("Der Preis darf nicht negativ sein.")

    def __repr__(self):
        """
        Returns a string representation of the product.
        """
        return f"Product(id={self.id}, name={self.name}, description={self.description}, price={self.price}, quantity={self.quantity})"